pub enum SASLMechanism {
AMQPlain,
Anonymous,
External,
Plain,
RabbitCrDemo,
}Expand description
The SASL mechanisms supported by RabbitMQ
Variants
AMQPlain
This is a legacy mechanism kept for backward compatibility
Anonymous
Anonymous authentication if supported by the RabbitMQ server
External
Delegate all authentication to the transport instead of the RabbitMQ server
Plain
Default plain login, this should be supported everywhere
RabbitCrDemo
A demo of RabbitMQ SecureOk mechanism, offers the same level of security as Plain
Implementations