Credentials

Struct Credentials 

pub struct Credentials { /* private fields */ }
Structure holding the username and password for authentication

Implementations

Source

impl Credentials

pub fn new(username: LongString, password: LongString) -> Self

Create a new Credentials instance with the given username and password

pub fn username(&self) -> &LongString

Get the username

pub fn password(&self) -> &LongString

Get the password

pub fn sasl_auth_string(&self, mechanism: SASLMechanism) -> LongString

Get the SASL authentication String for the given SASL mechanism

pub fn rabbit_cr_demo_challenge(&self) -> &'static str

Get the expected challenge for RabbitCrDemo mechanism

pub fn rabbit_cr_demo_answer(&self) -> LongString

Get the answer we need to give to the server for the RabbitCrDemo mechanism